pub struct RealESRGANUpscaleRequestBody {
pub image: InputImage,
pub height: Option<u16>,
pub width: Option<u16>,
}Fields
image: InputImageheight: Option<u16>Desired height of the output image.
Only one of width or height may be specified.
width: Option<u16>Desired width of the output image.
Only one of width or height may be specified.